#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_LESS_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_SCALAR_IS_LESS_HPP_INCLUDED

#include <boost/simd/operator/include/functions/scalar/is_less.hpp>

#endif
